==> webfwlog-0.91.tbz: www/data/webfwlog/include/config.php <==
<?php
/*
$Id: config.php.in,v 1.10 2005/03/07 00:49:26 bhockney Exp $
(C) 2003-2005 by Bob Hockney <zeus@ix.netcom.com>

config file parser

This code is distributed under the terms of GNU GPL
*/

$conffile = "/usr/local/etc/webfwlog.conf";
if (!($fp = fopen("$conffile", "r"))) die("Cannot open config file $conffile");

While (!feof($fp)) {
	$buffer = fgets($fp, 1024);
	if ($buffer[0] == "#") continue;
	$params[] = explode("=", "$buffer", 2);
}
fclose($fp);

// Failsafe defaults

$config["db"] = "none";
$config["wfwl_syslog"] = "/usr/local/bin/wfwl_syslog";
$config["syslog_dir"] = "/var/log";
$config["syslog_filespec"] = "messages";
$config["verbosity_level"] = 2;
$config["default_data_source"] = "ulogd";
$config["title"] = "Firewall Log Report";
$config["refresh"] = 0;
$config["dformat"] = "m/d/Y h:i:sA";
$config["report_order"] = "last_accessed";
$config["show_select_data_source"] = 0;
$config["allow_additional_where"] = 0;
$config["allow_be_verbose"] = 0;
$config["debug"] = 0;

foreach ($params as $param) {
	switch (trim("{$param[0]}")) {
		case "db":
		case "mysql_server":
		case "mysql_user":
		case "mysql_pass":
		case "mysql_db":
		case "mysql_table":
		case "mysql_ulog_db":
		case "mysql_ulog_table":
		case "mysql_wfwl_db":
		case "pgsql_server":
		case "pgsql_user":
		case "pgsql_pass":
		case "pgsql_db":
		case "pgsql_table":
		case "pgsql_ulog_schema":
		case "pgsql_ulog_table":
		case "pgsql_wfwl_schema":
		case "wfwl_syslog":
		case "syslog_dir":
		case "syslog_filespec":
		case "verbosity_level":
		case "default_data_source":
		case "data_source":
		case "title":
		case "refresh":
		case "dformat":
		case "report_order":
		case "show_select_data_source":
		case "allow_show_sql":
		case "allow_additional_where":
		case "allow_be_verbose":
		case "php_max_memory":
		case "php_timeout":
		case "php_update_timeout":
		case "session_save_path":
		case "debug":
			$config[trim("{$param[0]}")] = trim(trim("{$param[1]}"), "\"'");
			break;
		default:
			break;
	}

}
unset ($params);

if (!(isset ($config["mysql_ulog_db"])))
	$config["mysql_ulog_db"] = $config["mysql_db"];
if (!(isset ($config["mysql_ulog_table"])))
	$config["mysql_ulog_table"] = $config["mysql_table"];
if (!(isset ($config["mysql_wfwl_db"])))
	$config["mysql_wfwl_db"] = $config["mysql_ulog_db"];
if (!(isset ($config["pgsql_ulog_table"])))
	$config["pgsql_ulog_table"] = $config["pgsql_table"];
if (!(isset ($config["pgsql_ulog_schema"])))
	$config["pgsql_ulog_schema"] = "public";
if (!(isset ($config["pgsql_wfwl_schema"])))
	$config["pgsql_wfwl_schema"] = "public";

switch ("{$config["db"]}") {
	case "mysql":
		$database = $config["mysql_wfwl_db"];
		$ulogd = "{$config["mysql_ulog_db"]}";
		$ulog = "$ulogd.{$config["mysql_ulog_table"]}";
		$reports = "{$config["mysql_wfwl_db"]}.reports";
		$hostnames = "{$config["mysql_wfwl_db"]}.hostnames";
		$services = "{$config["mysql_wfwl_db"]}.services";
		$update = "{$config["mysql_wfwl_db"]}.tmp_update";
		$tmp_output = "{$config["mysql_wfwl_db"]}.tmp_output";
		$allrows = "{$config["mysql_ulog_db"]}.allrows";
		$output = "{$config["mysql_ulog_db"]}.output";
		$q = "`";
		$regexp = "REGEXP";
		$inet_aton="inet_aton";
		$inet_ntoa="inet_ntoa";
		$true = "1";
		break;
	case "pgsql":
		$database = $config["pgsql_db"];
		$ulogd = "{$config["pgsql_ulog_schema"]}";
		$allrows = "allrows";
		$output = "output";
		$tmp_output = "tmp_output";
		$q = "\"";
		$regexp = "~";
		$true = "TRUE";
		break;
	default:
		break;
}

 // show_sql is deprecated
if (isset($config["allow_show_sql"])) {
	$config["allow_be_verbose"] = "{$config["allow_show_sql"]}";
	unset ($config["allow_show_sql"]);
}

if (isset($config["data_source"])) {
	$config["default_data_source"] = "{$config["data_source"]}";
	unset ($config["data_source"]);
}

if (isset($config["php_max_memory"])) {
	ini_set("memory_limit", "{$config["php_max_memory"]}");
}

if (isset($config["php_timeout"])) {
	set_time_limit("{$config["php_timeout"]}");
}

$webfwlog_version = "0.91";

?>

==> webfwlog-0.92.tbz: www/data/webfwlog/include/config.php <==
<?php
/*
$Id: config.php.in,v 1.12 2006/03/03 17:27:38 bhockney Exp $
(C) 2003-2006 by Bob Hockney <zeus@ix.netcom.com>

config file parser

This code is distributed under the terms of GNU GPL
*/

$conffile = "/usr/local/etc/webfwlog.conf";
if (!($fp = fopen("$conffile", "r"))) die("Cannot open config file $conffile");

While (!feof($fp)) {
	$buffer = fgets($fp, 1024);
	if ($buffer[0] == "#") continue;
	$params[] = explode("=", "$buffer", 2);
}
fclose($fp);

// Failsafe defaults

$config["db"] = "none";
$config["wfwl_syslog"] = "/usr/local/bin/wfwl_syslog";
$config["syslog_dir"] = "/var/log";
$config["syslog_filespec"] = "messages";
$config["verbosity_level"] = 2;
$config["default_data_source"] = "ulogd";
$config["title"] = "Firewall Log Report";
$config["refresh"] = 0;
$config["dformat"] = "m/d/Y h:i:sA";
$config["report_order"] = "last_accessed";
$config["show_select_data_source"] = 0;
$config["allow_raw_sql"] = 0;
$config["allow_be_verbose"] = 0;
$config["debug"] = 0;

foreach ($params as $param) {
	switch (trim("{$param[0]}")) {
		case "db":
		case "mysql_server":
		case "mysql_user":
		case "mysql_pass":
		case "mysql_db":
		case "mysql_table":
		case "mysql_ulog_db":
		case "mysql_ulog_table":
		case "mysql_wfwl_db":
		case "pgsql_server":
		case "pgsql_user":
		case "pgsql_pass":
		case "pgsql_db":
		case "pgsql_table":
		case "pgsql_ulog_schema":
		case "pgsql_ulog_table":
		case "pgsql_wfwl_schema":
		case "wfwl_syslog":
		case "syslog_dir":
		case "syslog_filespec":
		case "verbosity_level":
		case "default_data_source":
		case "data_source":
		case "title":
		case "refresh":
		case "dformat":
		case "report_order":
		case "show_select_data_source":
		case "allow_show_sql":
		case "allow_additional_where":
		case "allow_raw_sql":
		case "allow_be_verbose":
		case "php_max_memory":
		case "php_timeout":
		case "php_update_timeout":
		case "session_save_path":
		case "debug":
			$config[trim("{$param[0]}")] = trim(trim("{$param[1]}"), "\"'");
			break;
		default:
			break;
	}

}
unset ($params);

if (!(isset ($config["mysql_ulog_db"])))
	$config["mysql_ulog_db"] = $config["mysql_db"];
if (!(isset ($config["mysql_ulog_table"])))
	$config["mysql_ulog_table"] = $config["mysql_table"];
if (!(isset ($config["mysql_wfwl_db"])))
	$config["mysql_wfwl_db"] = $config["mysql_ulog_db"];
if (!(isset ($config["pgsql_ulog_table"])))
	$config["pgsql_ulog_table"] = $config["pgsql_table"];
if (!(isset ($config["pgsql_ulog_schema"])))
	$config["pgsql_ulog_schema"] = "public";
if (!(isset ($config["pgsql_wfwl_schema"])))
	$config["pgsql_wfwl_schema"] = "public";

switch ("{$config["db"]}") {
	case "mysql":
		$database = $config["mysql_wfwl_db"];
		$ulogd = "{$config["mysql_ulog_db"]}";
		$ulog = "$ulogd.{$config["mysql_ulog_table"]}";
		$reports = "{$config["mysql_wfwl_db"]}.reports";
		$hostnames = "{$config["mysql_wfwl_db"]}.hostnames";
		$services = "{$config["mysql_wfwl_db"]}.services";
		$update = "{$config["mysql_wfwl_db"]}.tmp_update";
		$tmp_output = "{$config["mysql_wfwl_db"]}.tmp_output";
		$allrows = "{$config["mysql_ulog_db"]}.allrows";
		$output = "{$config["mysql_ulog_db"]}.output";
		$q = "`";
		$regexp = "REGEXP";
		$inet_aton="inet_aton";
		$inet_ntoa="inet_ntoa";
		$true = "1";
		break;
	case "pgsql":
		$database = $config["pgsql_db"];
		$ulogd = "{$config["pgsql_ulog_schema"]}";
		$allrows = "allrows";
		$output = "output";
		$tmp_output = "tmp_output";
		$q = "\"";
		$regexp = "~";
		$true = "TRUE";
		break;
	default:
		break;
}

 // show_sql is deprecated
if (isset($config["allow_show_sql"])) {
	$config["allow_be_verbose"] = "{$config["allow_show_sql"]}";
	unset ($config["allow_show_sql"]);
}

 // allow_additional_where is deprecated
if (isset($config["allow_additional_where"])) {
	$config["allow_raw_sql"] = "{$config["allow_additional_where"]}";
	unset ($config["allow_additional_where"]);
}

if (isset($config["data_source"])) {
	$config["default_data_source"] = "{$config["data_source"]}";
	unset ($config["data_source"]);
}

if (isset($config["php_max_memory"])) {
	ini_set("memory_limit", "{$config["php_max_memory"]}");
}

if (isset($config["php_timeout"])) {
	set_time_limit("{$config["php_timeout"]}");
}

$webfwlog_version = "0.92";

?>
